import http from "@/utils/request";

const dictUrl = "/api/v1/AdminDictionary"

interface DictRowQuery {
  parentId?: string
  parentValue?: string
  label: string
  labelEn?: string
  remark?: string
  value: string
  tag?: string
}

interface DictRowReturn {
  uuid: string
  parentId: string
  parentValue: string
  label: string
  labelEn: string
  remark: string
  value: string
  tag: string
  createTime: string
  createUserId: string
};
const DictParentURL = "/api/Dict/parents";
const DictChildURL = "/api/Dict/children";

// 获取父级字典
export function getParentDict(label: string): Promise<DictRowReturn[]> {
  return http({
    url: DictParentURL,
    method: 'GET',
    params: label
  })
}
// 新增父级字典
export function addParentDict(data: { label: string, value: string }) {
  return http({
    url: DictParentURL,
    method: 'POST',
    data
  })
}
// 更新父级字典
export function updateParentDict(uuid: string, data: { label: string }) {
  return http({
    url: `${DictParentURL}/${uuid}`,
    method: 'PUT',
    data
  })
}
// 删除父级字典
export function deleteParentDict(uuid: string) {
  return http({
    url: `${DictParentURL}/${uuid}`,
    method: 'DELETE',
  })
}
// 新增子级字典
/**
 * 
 * @param data 必需parentId, parentValue, label, value
 * @returns 
 */
export function addChildDict(data: DictRowQuery) {
  console.log("addChildDict", data);
  return http({
    url: DictChildURL,
    method: 'POST',
    data
  })
}
// 获取子级字典
/**
 * 
 * @param value 为父级value
 * @param tag 用逗号连接选择的tags数组
 * @returns 
 */
export function getDict(value: string, tag: string): Promise<DictRowReturn[]> {
  return http({
    url: DictChildURL,
    method: 'GET',
    params: { value, tag }
  })
}
// 更新子级字典
/**
 * 
 * @param data 必需label, value
 * @returns 
 */
export function updateChildDict(uuid: string, data: DictRowQuery) {
  console.log("updateChildDict", data);
  return http({
    url: `${DictChildURL}/${uuid}`,
    method: 'PUT',
    data
  })
}
// 删除子级字典
export function deleteChildDict(uuid: string) {
  return http({
    url: `${DictChildURL}/${uuid}`,
    method: 'DELETE',
  })
}